@@ -24,7 +24,7 @@
 #include "logger.h"
 #include "exceptions.h"
 #include "backends/rendering.h"
-#include "glmatrices.h"
+#include "backends/config.h"
 #include "compat.h"
 #include "scripting/flash/text/flashtext.h"
 
@@ -173,10 +173,11 @@ TextureBuffer::~TextureBuffer()
 	shutdown();
 }
 
+
 MatrixApplier::MatrixApplier()
 {
 	//First of all try to preserve current matrix
-	lsglPushMatrix();
+	getRenderThread()->lsglPushMatrix();
 
 	//TODO: implement smart stack flush
 	//Save all the current stack, compute using SSE the final matrix and push that one
@@ -187,11 +188,11 @@ MatrixApplier::MatrixApplier()
 MatrixApplier::MatrixApplier(const MATRIX& m)
 {
 	//First of all try to preserve current matrix
-	lsglPushMatrix();
+	getRenderThread()->lsglPushMatrix();
 
 	float matrix[16];
 	m.get4DMatrix(matrix);
-	lsglMultMatrixf(matrix);
+	getRenderThread()->lsglMultMatrixf(matrix);
 	getRenderThread()->setMatrixUniform(LSGL_MODELVIEW);
 }
 
@@ -199,16 +200,17 @@ void MatrixApplier::concat(const MATRIX& m)
 {
 	float matrix[16];
 	m.get4DMatrix(matrix);
-	lsglMultMatrixf(matrix);
+	getRenderThread()->lsglMultMatrixf(matrix);
 	getRenderThread()->setMatrixUniform(LSGL_MODELVIEW);
 }
 
 void MatrixApplier::unapply()
 {
-	lsglPopMatrix();
+	getRenderThread()->lsglPopMatrix();
 	getRenderThread()->setMatrixUniform(LSGL_MODELVIEW);
 }
 
+
 TextureChunk::TextureChunk(uint32_t w, uint32_t h)
 {
 	width=w;
@@ -654,9 +656,13 @@ void CairoTokenRenderer::executeDraw(cairo_t* cr)
 	cairoPathFromTokens(cr, tokens, scaleFactor, false);
 }
 
+StaticMutex CairoRenderer::cairoMutex = GLIBMM_STATIC_MUTEX_INIT;
+
+/* This implements IThreadJob::execute */
 void CairoRenderer::execute()
 {
-	if(width==0 || height==0)
+	Mutex::Lock l(cairoMutex);
+	if(width==0 || height==0 || !Config::getConfig()->isRenderingEnabled())
 	{
 		uploadNeeded = false;
 		return;
