@@ -76,6 +76,11 @@ public:
 		width = w;
 		height = h;
 	}
+	/* The widget must not be gtk_widget_destroy'ed in the destructor. This is done
+	 * by firefox.
+	 */
+	~PluginEngineData() {}
+
 	void stopMainDownload();
 	bool isSizable() const { return false; }
 	NativeWindow getWindowForGnash();
