@@ -173,7 +173,7 @@ private:
 	bool paused;
 	//Indicates whether the NetStream has been closed/threadAborted. This is reset at every play() call.
 	//We initialize this value to true, so we can check that play() hasn't been called without being closed first.
-	bool closed;
+	volatile bool closed;
 
 	enum CONNECTION_TYPE { CONNECT_TO_FMS=0, DIRECT_CONNECTIONS };
 	CONNECTION_TYPE peerID;
