@@ -38,6 +38,7 @@ const tiny_string AS3="http://adobe.com/AS3/2006/builtin";
 class Event;
 class ABCContext;
 class Template_base;
+class ASString;
 class method_info;
 struct call_context;
 struct traits_info;
@@ -413,54 +414,6 @@ public:
 			std::map<const ASObject*, uint32_t>& objMap) const;
 };
 
-/*
- * The AS String class.
- * The 'data' is immutable -> it cannot be changed after creation of the object
- */
-class ASString: public ASObject
-{
-CLASSBUILDABLE(ASString);
-private:
-	tiny_string toString_priv() const;
-	ASString();
-	ASString(const std::string& s);
-	ASString(const tiny_string& s);
-	ASString(const char* s);
-	ASString(const char* s, uint32_t len);
-public:
-	tiny_string data;
-	static void sinit(Class_base* c);
-	static void buildTraits(ASObject* o);
-	ASFUNCTION(_constructor);
-	ASFUNCTION(charAt);
-	ASFUNCTION(charCodeAt);
-	ASFUNCTION(concat);
-	ASFUNCTION(fromCharCode);
-	ASFUNCTION(indexOf);
-	ASFUNCTION(lastIndexOf);
-	ASFUNCTION(match);
-	ASFUNCTION(replace);
-	ASFUNCTION(search);
-	ASFUNCTION(slice);
-	ASFUNCTION(split);
-	ASFUNCTION(substr);
-	ASFUNCTION(substring);
-	ASFUNCTION(toLowerCase);
-	ASFUNCTION(toUpperCase);
-	ASFUNCTION(_toString);
-	ASFUNCTION(_getLength);
-	bool isEqual(ASObject* r);
-	TRISTATE isLess(ASObject* r);
-	number_t toNumber() const;
-	int32_t toInt();
-	uint32_t toUInt();
-	ASFUNCTION(generator);
-	//Serialization interface
-	void serialize(ByteArray* out, std::map<tiny_string, uint32_t>& stringMap,
-			std::map<const ASObject*, uint32_t>& objMap) const;
-	std::string toDebugString() { return std::string("\"") + std::string(data) + "\""; }
-};
-
 class Null: public ASObject
 {
 public:
@@ -627,6 +580,7 @@ public:
 class XMLList;
 class XML: public ASObject
 {
+friend class XMLList;
 private:
 	//The parser will destroy the document and all the childs on destruction
 	xmlpp::DomParser parser;
@@ -641,6 +595,7 @@ private:
 	bool constructed;
 	bool nodesEqual(xmlpp::Node *a, xmlpp::Node *b) const;
 	XMLList* getAllAttributes();
+	void getText(std::vector<_R<XML>> &ret);
 public:
 	XML();
 	XML(const std::string& str);
@@ -661,6 +616,8 @@ public:
 	ASFUNCTION(generator);
 	ASFUNCTION(_hasSimpleContent);
 	ASFUNCTION(_hasComplexContent);
+	ASFUNCTION(valueOf);
+	ASFUNCTION(text);
 	static void buildTraits(ASObject* o){};
 	static void sinit(Class_base* c);
 	void getDescendantsByQName(const tiny_string& name, const tiny_string& ns, std::vector<_R<XML> >& ret);
@@ -708,6 +665,8 @@ public:
 	ASFUNCTION(toXMLString);
 	ASFUNCTION(generator);
 	ASFUNCTION(descendants);
+	ASFUNCTION(valueOf);
+	ASFUNCTION(text);
 	_NR<ASObject> getVariableByMultiname(const multiname& name, GET_VARIABLE_OPTION opt);
 	void setVariableByMultiname(const multiname& name, ASObject* o);
 	bool hasPropertyByMultiname(const multiname& name, bool considerDynamic);
@@ -729,20 +688,24 @@ class RegExp: public ASObject
 CLASSBUILDABLE(RegExp);
 friend class ASString;
 private:
-	tiny_string re;
-	bool global;
-	bool ignoreCase;
-	bool extended;
-	bool multiline;
-	int lastIndex;
 	RegExp();
+	RegExp(const tiny_string& _re);
 public:
 	static void sinit(Class_base* c);
 	static void buildTraits(ASObject* o);
+	ASObject *match(const tiny_string& str);
 	ASFUNCTION(_constructor);
+	ASFUNCTION(generator);
 	ASFUNCTION(exec);
 	ASFUNCTION(test);
-	ASFUNCTION(_getGlobal);
+	ASFUNCTION(_toString);
+	ASPROPERTY_GETTER(bool, dotall);
+	ASPROPERTY_GETTER(bool, global);
+	ASPROPERTY_GETTER(bool, ignoreCase);
+	ASPROPERTY_GETTER(bool, extended);
+	ASPROPERTY_GETTER(bool, multiline);
+	ASPROPERTY_GETTER_SETTER(int, lastIndex);
+	ASPROPERTY_GETTER(tiny_string, source);
 };
 
 class Global : public ASObject
